@@ -5,7 +5,6 @@ import shutil
 import tempfile
 import unittest
 import sysconfig
-from copy import deepcopy
 
 from . import py38compat as os_helper
 
@@ -116,23 +115,6 @@ class DummyCommand:
         pass
 
 
-class EnvironGuard(object):
-    def setUp(self):
-        super(EnvironGuard, self).setUp()
-        self.old_environ = deepcopy(os.environ)
-
-    def tearDown(self):
-        for key, value in self.old_environ.items():
-            if os.environ.get(key) != value:
-                os.environ[key] = value
-
-        for key in tuple(os.environ.keys()):
-            if key not in self.old_environ:
-                del os.environ[key]
-
-        super(EnvironGuard, self).tearDown()
-
-
 def copy_xxmodule_c(directory):
     """Helper for tests that need the xxmodule.c source file.
 
