@@ -2,16 +2,13 @@
 import unittest
 import os
 import sys
-from test.support import run_unittest
 
 from distutils.command.build import build
 from distutils.tests import support
 from sysconfig import get_platform
 
-class BuildTestCase(support.TempdirManager,
-                    support.LoggingSilencer,
-                    unittest.TestCase):
 
+class BuildTestCase(support.TempdirManager, support.LoggingSilencer, unittest.TestCase):
     def test_finalize_options(self):
         pkg_dir, dist = self.create_dist()
         cmd = build(dist)
@@ -42,15 +39,8 @@ class BuildTestCase(support.TempdirManager,
         self.assertEqual(cmd.build_temp, wanted)
 
         # build_scripts is build/scripts-x.x
-        wanted = os.path.join(cmd.build_base,
-                              'scripts-%d.%d' % sys.version_info[:2])
+        wanted = os.path.join(cmd.build_base, 'scripts-%d.%d' % sys.version_info[:2])
         self.assertEqual(cmd.build_scripts, wanted)
 
         # executable is os.path.normpath(sys.executable)
         self.assertEqual(cmd.executable, os.path.normpath(sys.executable))
-
-def test_suite():
-    return unittest.TestLoader().loadTestsFromTestCase(BuildTestCase)
-
-if __name__ == "__main__":
-    run_unittest(test_suite())
