@@ -2,7 +2,6 @@
 import os
 import textwrap
 import unittest
-from test.support import run_unittest
 
 from distutils.command.check import check, HAS_DOCUTILS
 from distutils.tests import support
@@ -17,10 +16,7 @@ except ImportError:
 HERE = os.path.dirname(__file__)
 
 
-class CheckTestCase(support.LoggingSilencer,
-                    support.TempdirManager,
-                    unittest.TestCase):
-
+class CheckTestCase(support.LoggingSilencer, support.TempdirManager, unittest.TestCase):
     def _run(self, metadata=None, cwd=None, **options):
         if metadata is None:
             metadata = {}
@@ -48,9 +44,13 @@ class CheckTestCase(support.LoggingSilencer,
         # now let's add the required fields
         # and run it again, to make sure we don't get
         # any warning anymore
-        metadata = {'url': 'xxx', 'author': 'xxx',
-                    'author_email': 'xxx',
-                    'name': 'xxx', 'version': 'xxx'}
+        metadata = {
+            'url': 'xxx',
+            'author': 'xxx',
+            'author_email': 'xxx',
+            'name': 'xxx',
+            'version': 'xxx',
+        }
         cmd = self._run(metadata)
         self.assertEqual(cmd._warnings, 0)
 
@@ -63,11 +63,15 @@ class CheckTestCase(support.LoggingSilencer,
         self.assertEqual(cmd._warnings, 0)
 
         # now a test with non-ASCII characters
-        metadata = {'url': 'xxx', 'author': '\u00c9ric',
-                    'author_email': 'xxx', 'name': 'xxx',
-                    'version': 'xxx',
-                    'description': 'Something about esszet \u00df',
-                    'long_description': 'More things about esszet \u00df'}
+        metadata = {
+            'url': 'xxx',
+            'author': '\u00c9ric',
+            'author_email': 'xxx',
+            'name': 'xxx',
+            'version': 'xxx',
+            'description': 'Something about esszet \u00df',
+            'long_description': 'More things about esszet \u00df',
+        }
         cmd = self._run(metadata)
         self.assertEqual(cmd._warnings, 0)
 
@@ -75,9 +79,12 @@ class CheckTestCase(support.LoggingSilencer,
         for kind in ("author", "maintainer"):
             # ensure no warning when author_email or maintainer_email is given
             # (the spec allows these fields to take the form "Name <email>")
-            metadata = {'url': 'xxx',
-                        kind + '_email': 'Name <name@email.com>',
-                        'name': 'xxx', 'version': 'xxx'}
+            metadata = {
+                'url': 'xxx',
+                kind + '_email': 'Name <name@email.com>',
+                'name': 'xxx',
+                'version': 'xxx',
+            }
             cmd = self._run(metadata)
             self.assertEqual(cmd._warnings, 0)
 
@@ -117,12 +124,20 @@ class CheckTestCase(support.LoggingSilencer,
         self.assertEqual(cmd._warnings, 1)
 
         # let's see if we have an error with strict=1
-        metadata = {'url': 'xxx', 'author': 'xxx',
-                    'author_email': 'xxx',
-                    'name': 'xxx', 'version': 'xxx',
-                    'long_description': broken_rest}
-        self.assertRaises(DistutilsSetupError, self._run, metadata,
-                          **{'strict': 1, 'restructuredtext': 1})
+        metadata = {
+            'url': 'xxx',
+            'author': 'xxx',
+            'author_email': 'xxx',
+            'name': 'xxx',
+            'version': 'xxx',
+            'long_description': broken_rest,
+        }
+        self.assertRaises(
+            DistutilsSetupError,
+            self._run,
+            metadata,
+            **{'strict': 1, 'restructuredtext': 1}
+        )
 
         # and non-broken rest, including a non-ASCII character to test #12114
         metadata['long_description'] = 'title\n=====\n\ntest \u00df'
@@ -139,22 +154,30 @@ class CheckTestCase(support.LoggingSilencer,
         # Don't fail if there is a `code` or `code-block` directive
 
         example_rst_docs = []
-        example_rst_docs.append(textwrap.dedent("""\
+        example_rst_docs.append(
+            textwrap.dedent(
+                """\
             Here's some code:
 
             .. code:: python
 
                 def foo():
                     pass
-            """))
-        example_rst_docs.append(textwrap.dedent("""\
+            """
+            )
+        )
+        example_rst_docs.append(
+            textwrap.dedent(
+                """\
             Here's some code:
 
             .. code-block:: python
 
                 def foo():
                     pass
-            """))
+            """
+            )
+        )
 
         for rest_with_code in example_rst_docs:
             pkg_info, dist = self.create_dist(long_description=rest_with_code)
@@ -166,19 +189,10 @@ class CheckTestCase(support.LoggingSilencer,
             else:
                 self.assertEqual(len(msgs), 1)
                 self.assertEqual(
-                    str(msgs[0][1]),
-                    'Cannot analyze code. Pygments package not found.'
+                    str(msgs[0][1]), 'Cannot analyze code. Pygments package not found.'
                 )
 
     def test_check_all(self):
-
-        metadata = {'url': 'xxx', 'author': 'xxx'}
-        self.assertRaises(DistutilsSetupError, self._run,
-                          {}, **{'strict': 1,
-                                 'restructuredtext': 1})
-
-def test_suite():
-    return unittest.TestLoader().loadTestsFromTestCase(CheckTestCase)
-
-if __name__ == "__main__":
-    run_unittest(test_suite())
+        self.assertRaises(
+            DistutilsSetupError, self._run, {}, **{'strict': 1, 'restructuredtext': 1}
+        )
