@@ -4,7 +4,6 @@ import unittest
 
 from distutils.command.clean import clean
 from distutils.tests import support
-from test.support import run_unittest
 
 
 class cleanTestCase(support.TempdirManager, support.LoggingSilencer, unittest.TestCase):
@@ -45,11 +44,3 @@ class cleanTestCase(support.TempdirManager, support.LoggingSilencer, unittest.Te
         cmd.all = 1
         cmd.ensure_finalized()
         cmd.run()
-
-
-def test_suite():
-    return unittest.TestLoader().loadTestsFromTestCase(cleanTestCase)
-
-
-if __name__ == "__main__":
-    run_unittest(test_suite())
