@@ -16,7 +16,6 @@ from distutils.dir_util import (
 
 from distutils import log
 from distutils.tests import support
-from test.support import run_unittest
 
 
 class DirUtilTestCase(support.TempdirManager, unittest.TestCase):
@@ -134,11 +133,3 @@ class DirUtilTestCase(support.TempdirManager, unittest.TestCase):
         ):
             src = self.tempdirs[-1]
             dir_util.copy_tree(src, None)
-
-
-def test_suite():
-    return unittest.TestLoader().loadTestsFromTestCase(DirUtilTestCase)
-
-
-if __name__ == "__main__":
-    run_unittest(test_suite())
