@@ -3,7 +3,6 @@ import unittest
 import os
 import warnings
 
-from test.support import run_unittest
 from distutils.extension import read_setup_file, Extension
 
 from .py38compat import check_warnings
@@ -102,11 +101,3 @@ class ExtensionTestCase(unittest.TestCase):
         self.assertEqual(
             str(w.warnings[0].message), "Unknown Extension options: 'chic'"
         )
-
-
-def test_suite():
-    return unittest.TestLoader().loadTestsFromTestCase(ExtensionTestCase)
-
-
-if __name__ == "__main__":
-    run_unittest(test_suite())
