@@ -8,7 +8,7 @@ from distutils.errors import DistutilsTemplateError
 from distutils.filelist import glob_to_re, translate_pattern, FileList
 from distutils import filelist
 
-from test.support import captured_stdout, run_unittest
+from test.support import captured_stdout
 from distutils.tests import support
 
 from . import py38compat as os_helper
@@ -349,16 +349,3 @@ class FindAllTestCase(unittest.TestCase):
             os.symlink('.', link)
             files = filelist.findall(temp_dir)
             assert len(files) == 1
-
-
-def test_suite():
-    return unittest.TestSuite(
-        [
-            unittest.TestLoader().loadTestsFromTestCase(FileListTestCase),
-            unittest.TestLoader().loadTestsFromTestCase(FindAllTestCase),
-        ]
-    )
-
-
-if __name__ == "__main__":
-    run_unittest(test_suite())
