@@ -7,19 +7,20 @@ import sys
 import textwrap
 import unittest
 
+import pytest
 import jaraco.envs
 
 import distutils
 from distutils import sysconfig
 from distutils.ccompiler import get_default_compiler
 from distutils.unixccompiler import UnixCCompiler
-from distutils.tests import support
-from test.support import run_unittest, swap_item
+from test.support import swap_item
 
 from .py38compat import TESTFN
 
 
-class SysconfigTestCase(support.EnvironGuard, unittest.TestCase):
+@pytest.mark.usefixtures('save_env')
+class SysconfigTestCase(unittest.TestCase):
     def setUp(self):
         super(SysconfigTestCase, self).setUp()
         self.makefile = None
@@ -331,13 +332,3 @@ class SysconfigTestCase(support.EnvironGuard, unittest.TestCase):
             cmd, env={**os.environ, "PYTHONPATH": distutils_path}
         )
         assert out == "True"
-
-
-def test_suite():
-    suite = unittest.TestSuite()
-    suite.addTest(unittest.TestLoader().loadTestsFromTestCase(SysconfigTestCase))
-    return suite
-
-
-if __name__ == '__main__':
-    run_unittest(test_suite())
